
# Enum: reftype_options




URI: [nwb_schema_language:reftype_options](https://w3id.org/p2p_ld/nwb-schema-language/reftype_options)


## Other properties

|  |  |  |
| --- | --- | --- |

## Permissible Values

| Text | Description | Meaning | Other Information |
| :--- | :---: | :---: | ---: |
| ref | Reference to another group or dataset of the given target_type |  |  |
| reference | Reference to another group or dataset of the given target_type |  |  |
| object | Reference to another group or dataset of the given target_type |  |  |
| region | Reference to a region (i.e. subset) of another dataset of the given target_type |  |  |

